The Scientific and Technical Information eXchange (STIX) fonts are intended to satisfy the demanding needs of authors, publishers, printers, and others working in the scientific, medical, and technical fields.

The STIX Two fonts consist of one Math font, two variable text fonts (Roman and Italic), and eight static text (Regular to Bold in both roman and italic variants). Together, they provide a uniform set of fonts that can be used throughout the production process.

The STIX project began through the joint efforts of American Mathematical Society (AMS), American Institute of Physics (AIP), American Physical Society (APS), American Chemical Society (ACS), The Institute of Electrical and Electronic Engineers (IEEE), and Elsevier. These companies are collectively known as the STI Pub companies.

To contribute, see github.com/stipub/stixfonts.